==> aws_pdk-0.23.61.tar.gz: package/.types-compat/ts3.9/type-safe-api/project/codegen/infrastructure/cdk/generated-java-cdk-infrastructure-base-project.d.ts <==
import { Task } from "projen";
import { JavaProject, JavaProjectOptions } from "projen/lib/java";
import { CodeGenerationSourceOptions, GeneratedWithOpenApiGeneratorOptions } from "../../../types";
import { OpenApiGeneratorIgnoreFile } from "../../components/open-api-generator-ignore-file";
import { GenerationOptions } from "../../components/utils";
import { GeneratedHandlersProjects } from "../../generate";
import { GeneratedJavaRuntimeBaseProject } from "../../runtime/generated-java-runtime-base-project";
export interface GeneratedJavaInfrastructureBaseOptions extends JavaProjectOptions, GeneratedWithOpenApiGeneratorOptions {
}
export interface GeneratedJavaCdkInfrastructureBaseProjectOptions extends GeneratedJavaInfrastructureBaseOptions, CodeGenerationSourceOptions {
    /**
     * The generated java types
     */
    readonly generatedJavaTypes: GeneratedJavaRuntimeBaseProject;
    /**
     * Generated handlers projects
     */
    readonly generatedHandlers: GeneratedHandlersProjects;
}
export declare abstract class GeneratedJavaCdkInfrastructureBaseProject extends JavaProject {
    /**
     * Options configured for the project
     */
    protected readonly options: GeneratedJavaCdkInfrastructureBaseProjectOptions;
    /**
     * Source directory
     */
    protected readonly srcDir: string;
    /**
     * Java package name
     */
    protected readonly packageName: string;
    /**
     * Code generation task
     */
    protected readonly generateTask: Task;
    protected readonly openapiGeneratorIgnore: OpenApiGeneratorIgnoreFile;
    constructor(options: GeneratedJavaCdkInfrastructureBaseProjectOptions);
    buildGenerateCommandArgs: () => string;
    protected abstract buildOpenApiGeneratorOptions(): GenerationOptions;
}

==> aws_pdk-0.23.72.tar.gz: package/.types-compat/ts3.9/type-safe-api/project/codegen/infrastructure/cdk/generated-java-cdk-infrastructure-base-project.d.ts <==
import { Task } from "projen";
import { JavaProject, JavaProjectOptions } from "projen/lib/java";
import { CodeGenerationSourceOptions, GeneratedWithOpenApiGeneratorOptions } from "../../../types";
import { CodegenOptions } from "../../components/utils";
import { GeneratedHandlersProjects } from "../../generate";
import { GeneratedJavaRuntimeBaseProject } from "../../runtime/generated-java-runtime-base-project";
export interface GeneratedJavaInfrastructureBaseOptions extends JavaProjectOptions, GeneratedWithOpenApiGeneratorOptions {
}
export interface GeneratedJavaCdkInfrastructureBaseProjectOptions extends GeneratedJavaInfrastructureBaseOptions, CodeGenerationSourceOptions {
    /**
     * The generated java types
     */
    readonly generatedJavaTypes: GeneratedJavaRuntimeBaseProject;
    /**
     * Generated handlers projects
     */
    readonly generatedHandlers: GeneratedHandlersProjects;
}
export declare abstract class GeneratedJavaCdkInfrastructureBaseProject extends JavaProject {
    /**
     * Options configured for the project
     */
    protected readonly options: GeneratedJavaCdkInfrastructureBaseProjectOptions;
    /**
     * Source directory
     */
    protected readonly srcDir: string;
    /**
     * Java package name
     */
    protected readonly packageName: string;
    /**
     * Code generation task
     */
    protected readonly generateTask: Task;
    constructor(options: GeneratedJavaCdkInfrastructureBaseProjectOptions);
    buildGenerateCommandArgs: () => string;
    protected abstract buildCodegenOptions(): CodegenOptions;
}
